fnss.topologies.topology.Topology.add_star — FNSS 0.1.0 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.1.0 documentation »

# fnss.topologies.topology.Topology.add_star

`Topology.` `add_star`(nodes, **attr)

  Add a star.

  The first node in nodes is the middle of the star. It is connected to all other nodes.

  Parameters : | nodes : iterable container A container of nodes. attr : keyword arguments, optional (default= no attributes) Attributes to add to every edge in star.

  See also

  `add_path`, `add_cycle`

  Examples

      >>> G = nx.Graph()   # or DiGraph, MultiGraph, MultiDiGraph, etc
      >>> G.add_star([0,1,2,3])
      >>> G.add_star([10,11,12],weight=2)

### Navigation

- index
- modules |
- modules |
- FNSS 0.1.0 documentation »